summaryrefslogtreecommitdiff
path: root/fml/lib/FML/Process
diff options
context:
space:
mode:
authorfukachan <fukachan>2001-05-31 11:02:32 +0000
committerfukachan <fukachan>2001-05-31 11:02:32 +0000
commit3e5b1084f52cd3870bbe0bfc5c8cf11500fd451e (patch)
tree1210b070dfc2466c43cfa90e4e80e39fe301a29d /fml/lib/FML/Process
parent1149b16f28aa8f39ea7a405dcd826825125666c5 (diff)
downloadfml8-3e5b1084f52cd3870bbe0bfc5c8cf11500fd451e.tar.gz
fml8-3e5b1084f52cd3870bbe0bfc5c8cf11500fd451e.tar.bz2
fml8-3e5b1084f52cd3870bbe0bfc5c8cf11500fd451e.zip
clean up documents
Diffstat (limited to 'fml/lib/FML/Process')
-rw-r--r--fml/lib/FML/Process/Configure.pm15
1 files changed, 8 insertions, 7 deletions
diff --git a/fml/lib/FML/Process/Configure.pm b/fml/lib/FML/Process/Configure.pm
index e7476548..db845320 100644
--- a/fml/lib/FML/Process/Configure.pm
+++ b/fml/lib/FML/Process/Configure.pm
@@ -4,7 +4,7 @@
# Copyright (C) 2000,2001 Ken'ichi Fukamachi
# All rights reserved.
#
-# $FML: Configure.pm,v 1.21 2001/04/03 09:45:43 fukachan Exp $
+# $FML: Configure.pm,v 1.22 2001/05/29 16:21:16 fukachan Exp $
#
package FML::Process::Configure;
@@ -22,7 +22,7 @@ use FML::Config;
=head1 NAME
-FML::Process::Configure -- fmlconf and makefml wrapper
+FML::Process::Configure -- fmlconf and makefml main functions
=head1 SYNOPSIS
@@ -32,11 +32,10 @@ FML::Process::Configure -- fmlconf and makefml wrapper
=head1 DESCRIPTION
-FML::Process::Configure is the wrapper for fmlconf and makefml.
-
-See C<FML::Process::Flow> for each program flow.
-
-=head2 MODULES
+FML::Process::Configure provides the main function for
+C<fmlconf>
+ and
+C<makefml>.
These programs,
C<fmlconf> and C<makefml>,
@@ -44,6 +43,8 @@ bootstrap by using these modules in this order.
libexec/loader -> FML::Process::Switch -> FML::Process::Configure
+See C<FML::Process::Flow> for the flow detail.
+
=head1 METHODS
=head2 C<new($args)>